import { definePgTExtension } from "@postgresql-typed/util";
import { checkValue } from "./util/checkValue.js";
const SCHEMA = {
    $default: false,
    $schema: {
        type: "object",
        properties: {
            from: { type: "string" },
            to: { type: "string" },
        },
        required: ["from", "to"],
    },
    /* c8 ignore next 1 */
    $resolve: (value) => (typeof value === "object" ? value : false),
};
export default definePgTExtension({
    meta: {
        name: "tzswitcher",
        configKey: "tzswitcher",
    },
    setup(resolvedOptions, pgt) {
        const { timestamp, timestamptz, time, timetz } = resolvedOptions;
        /* c8 ignore next 1 */
        if (!timestamp && !timestamptz && !time && !timetz)
            return;
        pgt.hook("client:pre-query", data => {
            data.input.values = checkValue(data.input.values, resolvedOptions, "from", "to");
        });
        pgt.hook("client:post-query", data => {
            data.output.rows = checkValue(data.output.rows, resolvedOptions, "to", "from");
        });
    },
    schema: {
        timestamp: SCHEMA,
        timestamptz: SCHEMA,
        time: SCHEMA,
        timetz: SCHEMA,
    },
});
//# sourceMappingURL=index.js.map